@@ -96,7 +96,7 @@ def CLI():
             args.parameter = int(args.parameter)
 
         score = multiScore(args.matrix,args.resolution,args.chromosome,
-                            ).obtainOneScore(args.type,parameter=args.parameter,datatype=args.datatype,gt=args.gt)
+                            ).obtainOneScore(args.type,parameter=args.parameter,datatype=args.datatype,gt=args.gt,TADfile=args.TADfile)
         score.to_csv(args.outname + ".bedGraph", sep="\t", header=False, index=False)
 
         if args.draw:
@@ -238,7 +238,7 @@ def CLI():
         datafile = pd.read_csv(args.data,sep="\t",header=None)
         labels = list(datafile.iloc[:,0])
         samplelist = list(datafile.iloc[:,1])
-        if not args.corr and not args.heat and not args.line and not args.discrete:
+        if not args.corr and not args.heat and not args.line and not args.discrete and not args.anova:
             score = getMultiSamplesScore(samplelist,labels,args.resolution,args.chromosome,args.type,args.parameter,
                                         datatype=args.datatype,gt=args.gt)
         elif args.corr:
@@ -254,6 +254,20 @@ def CLI():
             msd.plotMultiDiscrete(plotpath,args.start,args.end)
             plt.savefig(args.outname+"_discrete.pdf")
             exit(0)
+        elif args.anova:
+            if args.end == 0:
+                print("Please specify a region to calculate p-value");exit(1)
+            ms = repQC(samplelist,labels,args.resolution,args.chromosome,args.type,args.parameter,datatype=args.datatype,gt=args.gt)
+            score = ms.score
+            plist,qlist = ms.anova_like(args.start,args.end)
+            df = pd.DataFrame()
+            df["chr"] = [args.chromosome]* len(range(args.start,args.end,args.resolution))
+            df["start"] = list(range(args.start,args.end,args.resolution))
+            df["end"] = df["start"] + args.resolution
+            df['pvalue'] = plist
+            df['qvalue'] = qlist
+            df.to_csv(args.outname+"_anova.txt",sep="\t",index=False)
+
         elif args.line or args.heat:
             ms = repQC(samplelist,labels,args.resolution,args.chromosome,args.type,args.parameter,
                         datatype=args.datatype,gt=args.gt)
@@ -289,6 +303,7 @@ def CLI():
     parser_samples.add_argument("--corr",action='store_true',help="Plot correlation for all samples",default=False)
     parser_samples.add_argument("--heat",action='store_true',help="Plot raw heatmap for all samples",default=False)
     parser_samples.add_argument("--line",action='store_true',help="Plot line chart for all samples",default=False)
+    parser_samples.add_argument("--anova",action='store_true',help="Plot line chart for all samples",default=False)
     parser_samples.add_argument("--discrete",action='store_true',help="Plot discrete heatmap for all samples",default=False)
     parser_samples.add_argument('-s','--start',type=int,help="Start sites for plotting",default=0)
     parser_samples.add_argument('-e','--end',type=int,help="End sites for plotting",default=0)
@@ -352,7 +367,7 @@ def CLI():
     parser.add_argument("-V","--version",help="Show h1d version",action='store_true',default=False)
     args = parser.parse_args()
     if args.version:
-        print("h1d version 0.1.9")
+        print("h1d version 0.1.11")
         exit(0)
     try:
         func = args.func
